Skip to main content

clipShare

Publish Python Package to PyPi

Check the PyPi Package here

A single TCP server/client bundle that allows you to sync your clipboard between systems.

Features

  1. Sync clipboard between systems.
  2. Has a Web UI. Server IP:Port or ngrok-tunnel-host
    • To view clipboard on mobile devices.
    • To sync clipboard if not using the Python client.
  3. Advertise the server on the local network.
  4. Authentication using passcode. (Passcode should be shared via some external safe channel)
  5. Scan for servers on the local network.
  6. The same script can be used as a server or client.
  7. Encrypted communication for clipboard sharing with AES Encryption (Key should be shared via some external safe channel)

Installation

pip install clipShare

Usage

Usage: 
    clipShare [... OPTIONS]
    

Options:
    -h, --help                      Show this help message and exit
    -s, --server [SERVER_PORT_NUMER], --server [SERVER_PORT_NUMER]
                                    Run as server on the specified port.
    -c, --client SERVER_IP:SERVER_PORT_NUMBER, --client SERVER_IP:SERVER_PORT_NUMBER
                                    Run as a client, that connects to specified server IP and port.
    -t, --serve-on-ngrok-tunnel     Enable Serve on ngrok tunnel. This option requires ngrok authtoken to be present in {current_dir}/ngrok-auth-token.txt
    -a, --advertise                 Enable Advertising server on the local network.
    -n, --name                      Name of the server to be advertised.
    -p, --passcode                  Passcode for authentication.
    -ep, --encryption-password      Encryption password for data transfer.
    -toh, --tcp-over-https          Enable TCP over HTTPS for ngrok tunnel.
    -d, --debug                     Enable debug mode.

Examples:
    clipShare -s 5000
    clipShare -s 5000 -d
    clipShare -s 5000 -a
    clipShare -s 5000 -p RandomPasscode -ep 5up3rS3cu3_3ncrY9t1on_P45sw0rd
    clipShare -s 5000 -p RandomPasscode -ep 5up3rS3cu3_3ncrY9t1on_P45sw0rd -t -a -d
    clipShare -c 192.168.0.1:8080
    clipShare -c -d
    clipShare -c -d -p RandomPasscode -ep 5up3rS3cu3_3ncrY9t1on_P45sw0rd
    clipShare -c "abc.com" -toh -d -p RandomPasscode -ep 5up3rS3cu3_3ncrY9t1on_P45sw0rd
    clipShare -c "abc.com:120" -d -p RandomPasscode -ep 5up3rS3cu3_3ncrY9t1on_P45sw0rd
    clipShare -c -d -p RandomPasscode -ep 5up3rS3cu3_3ncrY9t1on_P45sw0rd

Do you Want to help me to work more on Open-Source Projects like this?

Buy Me A Coffee so that I can get one more sleepless night to work on this kind of stuff.

Or use other sponsoring methods if you like.

Metadata

Release files for clipShare 0.1.5

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for clipShare 0.1.5
File Size Uploaded
clipshare-0.1.5.tar.gz 149.0 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for clipShare 0.1.5
File Interpreter ABI Platform
clipShare-0.1.5-py3-none-any.whl Python 3 none any Details

Total release size: 295.9 kB

Release files / clipshare-0.1.5.tar.gz

Download URL clipshare-0.1.5.tar.gz
Size 149.0 kB
Tags Source
SHA-256 checksum
How to use checksums
5eafb8507fd32237075d9cc10755cb6a5914fe9f4a2ea48cff4b1a203305151b
BLAKE2b-256 checksum
How to use checksums
b872574072b2c65e14ead566f77e4daa6fcb8fcb1bc1185569a9ad86ef357583
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/5.0.0 CPython/3.9.19

Release files / clipShare-0.1.5-py3-none-any.whl

Download URL clipShare-0.1.5-py3-none-any.whl
Size 146.9 kB
Tags Python 3
SHA-256 checksum
How to use checksums
a14efcebeac257294ad2667584db9393f63885df184f6703ca4636f960996953
BLAKE2b-256 checksum
How to use checksums
30659ab919c012877914b1f8eaee71a44376e7d633b1632fb4b08467e97998f8
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/5.0.0 CPython/3.9.19

Release history Release notifications | RSS feed

This release

0.1.5 This release

2 release files

0.1.4

2 release files

0.1.3

2 release files

0.1.2

2 release files

0.1.1

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page